Ibis Birdbrain

# Messages

Ibis Birdbrain communicates with the user, itself, and (eventually) other bots through `Messages`. A `Message` is a simple wrapper around text with metadata and optional `Attachments`.

## Usage

    from ibis_birdbrain.messages import Message, Messages, Email

    m1 = Message("Hello, world!")
    m1

    Message(df8f6f11-7362-47d8-b932-62424d3cba8d)

## Emails

Currently, the only implementation of `Message` that is viewable as a proper string is `Email`.

    e1 = Email("Hello")
    e2 = Email(", world!")

    messages = Messages([e1, e2])
    messages

    To:
    From:
    Subject:
    Sent at: 2024-03-05 09:03:08.698844
    Message: adca7673-ec5c-4377-bd33-b933fb423af7

    Hello

    Attachments:

    ---
    To:
    From:
    Subject:
    Sent at: 2024-03-05 09:03:08.698872
    Message: 22619ca0-0390-4eaf-951d-459ad636a13f

    , world!

    Attachments:

Back to top